@@ -25,6 +25,20 @@ def parse_options():
         help="put your cURL for staging"
     )
 
+    parser.add_option(
+        '--stag-har-folder',
+        dest='stag_har_folder',
+        default=None,
+        help="put your har folder path for staging"
+    )
+
+    parser.add_option(
+        '--prod-har-folder',
+        dest='prod_har_folder',
+        default=None,
+        help="put your har folder path for production"
+    )
+
     parser.add_option(
        '--skip-response',
         dest='skip_response',
